==> haskell-ghc-syntax-highlighter-0.0.9.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-KJ4DSqk73bJD8zNfAoasQC
key:                  ghc-syntax-highlighter-0.0.9.0-KJ4DSqk73bJD8zNfAoasQC
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  b9a6bfd5809e2e5628789c60a9512fde
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-KJ4DSqk73bJD8zNfAoasQC
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syntax-highlighter-0.0.9.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-HEjokwPus5YLRLcPPp0rtG
key:                  ghc-syntax-highlighter-0.0.9.0-HEjokwPus5YLRLcPPp0rtG
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  99e0be6702968506906389e330f78c1e
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-HEjokwPus5YLRLcPPp0rtG
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
